summaryrefslogtreecommitdiffstats
path: root/Utilities/cmcurl/lib/pop3.h
diff options
context:
space:
mode:
Diffstat (limited to 'Utilities/cmcurl/lib/pop3.h')
-rw-r--r--Utilities/cmcurl/lib/pop3.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/Utilities/cmcurl/lib/pop3.h b/Utilities/cmcurl/lib/pop3.h
index 7bc53aa..a8e697c 100644
--- a/Utilities/cmcurl/lib/pop3.h
+++ b/Utilities/cmcurl/lib/pop3.h
@@ -11,7 +11,7 @@
*
* This software is licensed as described in the file COPYING, which
* you should have received as part of this distribution. The terms
- * are also available at http://curl.haxx.se/docs/copyright.html.
+ * are also available at https://curl.haxx.se/docs/copyright.html.
*
* You may opt to use, copy, modify, merge, publish, distribute and/or sell
* copies of the Software, and permit persons to whom the Software is
@@ -45,9 +45,9 @@ typedef enum {
POP3_LAST /* never used */
} pop3state;
/* This POP3 struct is used in the SessionHandle. All POP3 data that is
connection-oriented must be in pop3_conn to properly deal with the fact that
- perhaps the SessionHandle is changed between the times the connection is
+ perhaps the Curl_easy is changed between the times the connection is
used. */
struct POP3 {
curl_pp_transfer transfer;
@@ -45,9 +45,9 @@ typedef enum {
POP3_LAST /* never used */
} pop3state;
-/* This POP3 struct is used in the SessionHandle. All POP3 data that is
+/* This POP3 struct is used in the Curl_easy. All POP3 data that is
connection-oriented must be in pop3_conn to properly deal with the fact that